![](assets/Bottom_up.svg)
# Weclome to my profile!
<p>nanocode38</p>
<p align="left">
<a target="blank"><img align="center" src="/src/Avatar.jpg" alt="nanocode38" height="90" width="90" /></a>
<p>
</p>


<!--   my-icons -->
<p align="center">
    <a href="https://github.com/nanocode38/nanocode38"><img src="https://img.shields.io/badge/status-updating-brightgreen.svg"></a>
    <a href="https://github.com/python/cpython"><img src="https://img.shields.io/badge/Python-3.13-FF1493.svg"></a>
    <a href="https://github.com/nanocode38/nanocode38/graphs/contributors"><img src="https://img.shields.io/github/contributors/nanocode38/nanocode38?color=red"></a>
    <a href="https://github.com/nanocode38/nanocode38/stargazers"><img src="https://img.shields.io/github/stars/nanocode38/nanocode38.svg?logo=github"></a>
    <a href="https://github.com/nanocode38/nanocode38/network/members"><img src="https://img.shields.io/github/forks/nanocode38/nanocode38.svg?color=blue&logo=github"></a>
    <img src="https://visitor-badge.laobi.icu/badge?page_id=nanocode38.nanocode38" alt="visitors"/>   
</p>

<!--   my-header-img -->
![](./src/header_.png)

<a href="https://www.python.org/"><img src="https://upload.wikimedia.org/wikipedia/commons/c/c3/Python-logo-notext.svg" align="right" height="48" width="48" ></a>

<!--   my-ticker -->    
[![Typing SVG](https://readme-typing-svg.herokuapp.com?color=%2336BCF7&center=true&vCenter=true&width=600&lines=Hi+there+👋,+I+am+nanocode38;+I+am+a+14-year-old+boy.;+Welcome+to+My+Profile!;+Over+6+years+of+programming+experience;Always+learning+new+things+;Python+learning+enthusiast;)](https://git.io/typing-svg)


<!--   skyline  3D  -->
<a href="https://skyline.github.com/BEPb/2022"><img src="./assets/Web.gif" alt="" width="auto" height="auto" /></a>
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    
<!--   my-skils -->

| Property                                        | Data                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |
|-------------------------------------------------| |
| **Language / IDE**                              | ![Python Badge](https://img.shields.io/badge/-Python-3776AB?style=flat&logo=Python&logoColor=white) ![Pycharm Badge](https://img.shields.io/badge/-Pycharm-3776AB?style=flat&logo=Pycharm&logoColor=white) ![C++](https://img.shields.io/badge/-C++-66CC66?style=flat&logo=C%2B%2B&logoColor=00599C)&nbsp; ![Bash](https://img.shields.io/badge/-Bash-444444?style=flat&logo=GnuBash)&nbsp;                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
| **Domain Knownledge**                           | [![Machine Learning Badge](https://img.shields.io/badge/-Machine%20Learning-01D277?style=flat&logoColor=white)](https://github.com/BEPb/BEPb) [![Computer Science Development Badge](https://img.shields.io/badge/-Computer%20Science-FAB040?style=flat&logoColor=white)](https://github.com/search?q=user%3ABEPb&type=Repositories) [![Electrical Engineering Development Badge](https://img.shields.io/badge/-Electrical%20Engineering-4C8CBF?style=flat&logoColor=white)](https://github.com/search?q=user%3ABEPb&type=Repositories) [![Software Development Badge](https://img.shields.io/badge/-Software%20Development-FF6600?style=flat&logoColor=white)](https://github.com/search?q=user%3ABEPb&type=Repositories)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
| **CI / CD**                                     | [![Markdown Badge](https://img.shields.io/badge/-Markdown-2088FF?style=flat&logo=Markdown&logoColor=white)](https://github.com/BEPb/BEPb) ![Git](https://img.shields.io/badge/-Git-004400?style=flat&logo=git)&nbsp; ![GitHub](https://img.shields.io/badge/-GitHub-444444?style=flat&logo=github)&nbsp; ![GitLab](https://img.shields.io/badge/-GitLab-444444?style=flat&logo=GitLab)&nbsp;  [![](https://img.shields.io/badge/-Docker-2496ED?style=flat-square&logo=docker&logoColor=white)](https://www.docker.com) [![](https://img.shields.io/badge/-PyCharm-000000?style=flat-square&logo=pycharm&logoColor=white)](https://www.jetbrains.com/pycharm/) [![](https://img.shields.io/badge/-VS_Code-007ACC?style=flat-square&logo=visual-studio-code&logoColor=white)](https://code.visualstudio.com)|                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |
| **Machine Learning / Deep Learning frameworks** | ![PyTorch](http://img.shields.io/badge/-PyTorch-eee?style=flat-square&logo=pytorch&logoColor=EE4C2C) ![ChatGPT](https://img.shields.io/badge/-ChatGPT-444444?style=flat&logo=ChatGPT)&nbsp; ![OpenCV](https://img.shields.io/badge/-OpenCV-444444?style=flat&logo=OpenCV)&nbsp; |


## 📎 About me:

| Property    | Data                                       |
|-------------|--------------------------------------------|
| **Name:**     | nanocode38                                 |
| **Age:**        |               14                           |
| **Gender:**     | ♂                                          |   
| **Email:**      | nanocode38@88.com  |
| **Phone:**      | +86 15867244980 (+86 18258770302)          |
| **WeChat:**     | nanocode38   (Nickname: nanocode38)        |
| **QQ:**         | 2602422835                                 |
| **GitHub:**     | [https://github.com/nanocode38](https://github.com/nanocode38)|
| **Address:**    | Ningbo, Zhejiang, China                    |
| **Pet Phrase:** | 没有, 荣耀!, Glory!, 为了梅林的荣耀!, 我丢!, 卧艹! |    
| **Learned language:** | Chinese(perfection), Python(perfection), C++(proficiency), English(proficiency), JavaScript / TypeScript(grasp), C#(understand), PowerShell(understand), Bash(understand), HTML/CSS(understand)|
| **Hobbies:**    | Listening to English songs, Listening to absolute music, Reading science fiction, Learn all about the computer things, Coding, Play Basketball|
| **Motto:**      | <Too much !>|
| **Favourit Color:** | deep purple(#9400D3), light orange(#FFA500), Klein Blue(#002FA7), black and light red(#000000 and #FF0000) |
| **Favourit Number:**| 3, 33, 333, 3333, 50288, 333333, π(PI), i, φ(fai, golden ratio)|
| **Favourit Plane Figure:** | ◣(right triangle) |
| **Favourite Formula:**| $e^{i\pi} + 1 = 0$,  $x = \frac{-b \pm \sqrt{b^2 - 4ac}}{2a}$|
| **Profile:** | A lazy, science-fiction-loving junior saltwater programmer dreams of becoming a middle saltwater|


## 📫 How to Reach me:
<p align="left">
<a href="https://2602422835@qq.com" target="blank"><img align="center" src="https://raw.githubusercontent.com/nanocode38/nanocode38/master/assets/gmail.svg" alt="nanocode38" height="30" width="30" /></a>




![](assets/Bottom_down.svg)